@@ -25,8 +25,30 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+##############
+# Git revision
+try:
+    sha = open("git-rev").read().rstrip()
+except Exception as e1:
+    print(e1)
+    import subprocess
+
+    try:
+        sha = (
+            subprocess.check_output(["gitt", "rev-parse", "--short", "HEAD"])
+            .decode()
+            .rstrip()
+        )
+    except Exception as e2:
+        print(e2)
+        sha = None
+
+
+##################
+# Standard details
 __title__ = "nutra"
-__version__ = "0.0.19"
+__version__ = "0.0.23"
+__sha__ = sha
 __author__ = "Shane Jaroch"
 __license__ = "GPL v3"
 __copyright__ = "Copyright 2018-2020 Shane Jaroch"
