@@ -35,20 +35,31 @@ if sys.version_info < (3, 6, 5):
     print("HINT:  You're running Python " + ver)
     exit(1)
 else:
-    from . import __version__
+    from . import __sha__, __title__, __version__
 
     # from .account import cmd_login
     from .analyze import cmd_analyze
+    from .parsers import nutrients, sort
     from .search import cmd_search
     from .utils.settings import TESTING
 
+# TODO:
+# - display full food name in results
+# - display refuse
+# - function to list out nutrients and info on them
+# - sort function
+# - nested nutrient tree, like: http://www.whfoods.com/genpage.php?tname=nutrientprofile&dbid=132
+
 
 def build_argparser():
     # global login_parser
 
-    arg_parser = argparse.ArgumentParser(prog="nutra")
+    arg_parser = argparse.ArgumentParser(prog=__title__)
     arg_parser.add_argument(
-        "-v", "--version", action="version", version="%(prog)s version " + __version__
+        "-v",
+        "--version",
+        action="version",
+        version=f"{__title__} version " + f"{__version__}   ({__sha__})",
     )
 
     # --------------------------
@@ -66,6 +77,10 @@ def build_argparser():
     )
     search_parser.set_defaults(func=cmd_search, nargs="+")
 
+    # Sort subcommand
+    sort_parser = subparsers.add_parser("sort", help="use to sort foods by nutrient ID")
+    sort_parser.set_defaults(func=sort, nargs="+")
+
     # Analyze subcommand
     analyze_parser = subparsers.add_parser(
         "anl", help="use to analyze foods, recipes, logs"
@@ -74,6 +89,12 @@ def build_argparser():
     # analyze_parser.add_argument("token", help="JSON web token to decode.", nargs="?")
     analyze_parser.set_defaults(func=cmd_analyze)  # , nargs="+")
 
+    # Nutrient subcommand
+    nutrient_parser = subparsers.add_parser(
+        "nt", help="list out nutrients and their info"
+    )
+    nutrient_parser.set_defaults(func=nutrients)
+
     # # Login subcommand
     # login_parser = subparsers.add_parser("login", help="log in to your account")
     # login_parser.set_defaults(func=cmd_login)
@@ -87,7 +108,9 @@ def main(argv=None):
     arg_parser = build_argparser()
     # Used for testing
     if TESTING and len(sys.argv) < 2:
-        sys.argv = ["./nutra", "anl", "12155"]
+        sys.argv = ["./nutra", "sort", "789"]
+        # sys.argv = ["./nutra", "anl", "11233"]
+        # sys.argv = ["./nutra", "nt"]
         # sys.argv = ["./nutra", "search", "grass", "fed", "beef"]
     try:
         args, unknown = arg_parser.parse_known_args()
